pro bin2lat6,data,d6 
;=====================================================================
;@***h*  MW_Sounder_FCDR/bin2lat6.pro
;
; NAME
;        bin2lat6.pro
;
; LOCATION
;        $SRC_DIR/Src_IDL/
;
; DESCRIPTION:
;              IDL routine to open the given file containing Standard
;              Atmosphere data, read in the contents, interpolate values
;              to the given pressure levels, and return the results.
;
; EXTERNALS:
;              none.
;
; USAGE:
;              The RUN parameters specifying the data to process are set
;              directly below this header. The user needs to edit these
;              values to process the desired values and then execute the
;              program from within IDL.
;
; INPUTS:
;              Grid data
;
; OUTPUTS:
;              Mean of data in latitude scopes
;
; AUTHOR:
;              Liang Peng
;
; REVISIONS:
;              Patrick Callaghan (Formatted for CDR)
;
;
; COPYRIGHT
;              © University Corporation for Atmospheric Research (UCAR) 2011.
;              All rights reserved. Please refer to the UCAR copyright
;              statement in the main directory
;
;@*****
;=====================================================================

;Set latitude scope
;--------------------------------------
if n_elements(latlim1) eq 0 then latlim1 = [-90, 60, 20,-20,-60,-90]
if n_elements(latlim2) eq 0 then latlim2 = [ 90, 90, 60, 20,-20,-60]

;Set initial output data
;--------------------------------------
d6 = fltarr(n_elements(latlim1))+!values.d_nan

;Set latitide
;--------------------------------------
lat = data
nlat = n_elements(data[0,*])
nlon = n_elements(data[*,0])
for ilon = 0,nlon-1 do begin
  lat[ilon,*] = findgen(nlat)*180./nlat+180./nlat/2-90
endfor
clat = cos(lat/180*!dpi)

;Set output data
;--------------------------------------
for ilat = 0,n_elements(latlim1)-1 do begin
  id = where(finite(data) and lat gt latlim1[ilat] and lat lt latlim2[ilat])
  if id[0] gt -1 then begin
    d6[ilat] = total(data[id]*clat[id])/total(clat[id])
  endif
endfor

end
