pro msu_parameter,noaa,pl_noaa,k_noaa,e_1a_noaa,e_2a_noaa,e_1b_noaa,e_2b_noaa
;=====================================================================
;@***h*  MW_Sounder_FCDR/msu_parameter.pro
;
; NAME
;        msu_parameter.pro
;
; LOCATION
;        $SRC_DIR/Src_IDL/
;
; DESCRIPTION: 
;              IDL routine to define central wave number (unit is cm-1) 
;              define the warm target calibration coefficients
;
; EXTERNALS:   
;              none.
;
; USAGE:       
;              The RUN parameters specifying the data to process are set 
;              directly below this header. The user needs to edit these 
;              values to process the desired values and then execute the 
;              program from within IDL.
;
; INPUTS:   
;              Mission name
;
; OUTPUTS:      
;              Central wave number and warm target calibration coefficients
;
; AUTHOR:      
;              Liang Peng / Xinjia Zhou / Ben Ho (?)
;
; REVISIONS:   
;              Liang Peng (Formatted for CDR)
;
;
; COPYRIGHT
;              © University Corporation for Atmospheric Research (UCAR) 2011.
;              All rights reserved. Please refer to the UCAR copyright 
;              statement in the main directory
;  
;@*****
;=====================================================================

; define the central wave number (unit is cm-1)
;---------------------------------------------
if noaa eq 'noaa14' or $
   noaa eq 'noaa11' or $
   noaa eq 'noaa10' or $
   noaa eq 'noaa9'  or $
   noaa eq 'noaa8'  then pl_noaa = [1.6779, 1.7927, 1.8334, 1.9331]

if noaa eq 'noaa12' then pl_noaa = [1.6799, 1.7927, 1.8334, 1.9331]

if noaa eq 'noaa7'  then pl_noaa = [1.6779, 1.7927, 1.8337, 1.9331]

if noaa eq 'noaa6'  or $
   noaa eq 'tiros'  then pl_noaa = [1.6779, 1.7927, 1.8337, 1.9331]  ;pl_noaa = [1.6599, 1.7734, 1.6488, 1.7385]

; define the warm target calibration coefficients
;---------------------------------------------
if noaa eq 'tiros' then begin
  k_noaa = [495.6 , 107.8]
  e_1a_noaa = [ 29.10, .42596, .3187E-04]
  e_2a_noaa = [ 27.55, .42787, .3185E-04]
  e_1b_noaa = [ 29.05, .42710, .3206E-04]
  e_2b_noaa = [ 28.95, .42836, .3175E-04]
endif else if noaa eq 'noaa6' then begin
  k_noaa = [495.6 , 107.8]
  e_1a_noaa = [29.3271, .425427 , .3165629E-04]
  e_2a_noaa = [29.3083, .4260801, .314991E-04]
  e_1b_noaa = [29.2923, .426132 , .315241E-04]
  e_2b_noaa = [29.3731, .4255765, .317602E-04]
endif else if noaa eq 'noaa7' then begin
  k_noaa = [495.6 , 107.8]
  e_1a_noaa = [28.976, .42694, .31737E-04]
  e_2a_noaa = [28.995, .42627, .31775E-04]
  e_1b_noaa = [28.945, .42628, .31603E-04]
  e_2b_noaa = [28.964, .42498, .31389E-04]
endif else if noaa eq 'noaa8' then begin
  k_noaa = [495.6 , 107.8]
  e_1a_noaa = [29.4857, .4247172, .320960E-04]
  e_2a_noaa = [29.3123, .4326844, .3282283E-04]
  e_1b_noaa = [29.3471, .4247339, .3165123E-04]
  e_2b_noaa = [27.9719, .4285466, .3095837E-04]
endif else if noaa eq 'noaa9' then begin
  k_noaa = [495.6 , 107.8]
  e_1a_noaa = [29.4294, .4283514, .3223351E-04]
  e_2a_noaa = [29.2639, .4338180, .3334592E-04]
  e_1b_noaa = [29.5416, .4248521, .3188156E-04]
  e_2b_noaa = [29.5778, .4243732, .3264424E-04]
endif else if noaa eq 'noaa10' then begin
  k_noaa = [495.6 , 107.8]
  e_1a_noaa = [ 29.2589, .4245799, .3169871E-04]
  e_2a_noaa = [ 29.4633, .4250778, .3192864E-04]
  e_1b_noaa = [ 29.2350, .4289328, .3232162E-04]
  e_2b_noaa = [ 29.4680, .4275379, .3221571E-04]
endif else if noaa eq 'noaa11' then begin
  k_noaa = [495.6 , 107.8]
  e_1a_noaa = [ 29.1014, .4242637, .3162073E-04]
  e_2a_noaa = [ 28.9481, .4277704, .3185110E-04]
  e_1b_noaa = [ 28.9854, .4269018, .3170732E-04]
  e_2b_noaa = [ 29.0424, .4274570, .3191209E-04]
endif else if noaa eq 'noaa12' then begin
  k_noaa = [495.6 , 107.8]
  e_1a_noaa = [ 29.3970, .4256561, .3238697E-04]
  e_2a_noaa = [ 28.4527, .4293800, .2974601E-04]
  e_1b_noaa = [ 28.1854, .4302196, .2920356E-04]
  e_2b_noaa = [ 28.9588, .4276377, .3033068E-04]
endif else if noaa eq 'noaa14' then begin
  k_noaa = [495.6 , 107.8]
  e_1a_noaa = [ 29.003197, .429363,  .3144484E-04]
  e_2a_noaa = [ 28.514892, .4280371, .3028803E-04]
  e_1b_noaa = [ 28.455605, .428430,  .3021258E-04]
  e_2b_noaa = [ 29.113998, .425768,  .3159801E-04]
endif

end
