@bin2lat6.pro
pro sno_step4_satraobbias_msu
;=====================================================================
;@***h*  MW_Sounder_FCDR/sno_step4_satraobbias_msu.pro
; 
; NAME
;        sno_step4_intersatbias_msu.pro
; 
; LOCATION
;        $SRC_DIR/Src_IDL/
;
; DESCRIPTION: 
;              For specified range of Julian days, this program read in 
;              the MSU gridded rebuilt BTs, RAOB gridded BTs and generate 
;              the biases between RAOB and NOAA14 written to an IDL data 
;              file for later use.
; 
; EXTERNALS:   
;              @bin2lat6.pro
; 
; USAGE:       
;              The RUN parameters specifying the data to process are set 
;              directly below this header. The user needs to edit these 
;              values to process the desired values and then execute the 
;              program from within IDL.
; 
; INPUTS:      
;              Rebuilt NOAA grided brighness temperature:
;                $InPath_noaa/
;
;              Rebuilt GPS simulated MSU grided brighness temperature:
;                $InPath_raob/
; 
; OUTPUTS:     
;              Inter satellite biases of NOAA and GPS 
;                $OutPath/
; 
; AUTHOR:      
;              Liang Peng / Ben Ho (?)
; 
; REVISIONS:   
;              Liang Peng (Formatted for CDR)
;
;
; COPYRIGHT
;              © University Corporation for Atmospheric Research (UCAR) 2011.
;              All rights reserved. Please refer to the UCAR copyright 
;              statement in the main directory
;
;@*****
;=====================================================================


;**************************************************************************
; Set RUN parameters here:
;           JD_BEG = The begining Julian day to process
;           JD_END = The ending Julian day to process
;             noaa = Mission name to process 
;      Inpath_noaa = Path to rebuild pixel level data
;      Inpath_raob = Path to GPS simulated MSU data
;          OutPath = Path to output data
;             inol = Number of guess value
;
;              Path values should contain a trailing '/'
;**************************************************************************
JD_BEG = julday( 1, 1,1995)
JD_END = julday(12,31,2004)
noaa = 'noaa14'
Inpath_noaa = '../Data/tmp/sno/rebuild/grid/'
Inpath_raob = '../Data/tmp/simulate/raob_amsu_grid/'
Inpath_raob = '/home/penglian/Data/version1/forward_fast/grid/raob_vaisala_amsu07_new1/'
Outpath     = '../Data/tmp/sno/rebuild/bias/'
inol = 0
;*********************************************************
; End of RUN parameters
;*********************************************************

;
; Set Julian days that will be dealwithed
;-----------------------------------------------------------------------
jds = timegen(start=JD_BEG,final=JD_END,unit='day')

;
; Set Bias initial values
;-----------------------------------------------------------------------
bias = fltarr(6,n_elements(jds))+!values.d_nan 
tb_noaa = fltarr(6,n_elements(jds))+!values.d_nan
tb_raob = fltarr(6,n_elements(jds))+!values.d_nan
tw_noaa = fltarr(6,n_elements(jds))+!values.d_nan

;
; Loop over the Julian days to process
;----------------------------------
for ijd = 0,n_elements(jds)-1 do begin

  ;
  ; Set the month and year
  ;----------------------------------
  jd = jds[ijd]
  caldat,jd,month_loop,dom_loop,year_loop
  doy_loop = jd - julday(1,0,year_loop)
  print,'------------------------'
  print,year_loop,month_loop,dom_loop,noaa
  print,'------------------------'

  ;
  ; Set input file names
  ;----------------------------------
  infile_noaa = Inpath_noaa+string(year_loop,f='(i4.4)')+string(month_loop,f='(i2.2)')+'/'+$
            string(year_loop,f='(i4.4)')+string(doy_loop,f='(i3.3)')+'_'+noaa+'_nc'
  infile_raob = Inpath_raob+string(year_loop,f='(i4.4)')+string(doy_loop,f='(i3.3)')+'_nc'
  print,infile_noaa
  print,infile_raob

  ;
  ; Read in first warm target temperature
  ; ---------------------------------
  if file_test(infile_noaa) and n_elements(tw0_noaa) eq 0 then begin
    ncid = NCDF_OPEN(infile_noaa,/NOWRITE)
    vd = NCDF_VARID(ncid, 'tbwbin')
    NCDF_VARGET, ncid,  vd, tbwbin
    NCDF_CLOSE, ncid
    id = where(tbwbin lt 50)
    if id[0] gt -1 then tbwbin[id] = !values.d_nan
    bin2lat6,tbwbin,tw0_noaa
  endif

  ;
  ; Read in brightness temperature
  ; ---------------------------------
  if ~file_test(infile_noaa) then goto,next
  if ~file_test(infile_raob) then goto,next

  ncid = NCDF_OPEN(infile_noaa,/NOWRITE)
  var = ['tbbin'+string(inol,f='(i2.2)'),'tbwbin']
  for iv = 0,n_elements(var)-1 do begin
    vd = NCDF_VARID(ncid, var[iv])
    rt=execute('NCDF_VARGET, ncid,  vd, '+var[iv]+'_noaa')
  endfor
  NCDF_CLOSE, ncid

  ncid = NCDF_OPEN(infile_raob,/NOWRITE)
  vd = NCDF_VARID(ncid, 'bt_bin')
  NCDF_VARGET, ncid,  vd, tbbin_raob
  NCDF_CLOSE, ncid

  rt=execute('tbbin_noaa = '+'tbbin'+string(inol,f='(i2.2)')+'_noaa')
 
  ;
  ; Caculate the bias
  ; --------------------------------- 
  id = where(tbbin_noaa lt 50 or tbbin_raob lt 50)
  if id[0] gt -1 then begin 
    tbbin_noaa[id] = !values.d_nan
    tbbin_raob[id] = !values.d_nan
  endif

  dbt = tbbin_raob-tbbin_noaa
  bin2lat6,dbt,dlat6
  bias[*,ijd] = dlat6

  bin2lat6,tbbin_noaa,tblat_noaa
  bin2lat6,tbbin_raob, tblat_raob

  tb_noaa[*,ijd] = tblat_noaa
  tb_raob [*,ijd] = tblat_raob

  tbwbin_noaa[id] = !values.d_nan
  bin2lat6,tbwbin_noaa,twlat_noaa
  tw_noaa[*,ijd] = twlat_noaa
  next:
endfor

;
; Save data
; -----------------------------------
Outfile = Outpath+'raob-'+noaa+'_nol'+string(inol,f='(i2.2)')+'.sav'
jds_bias = jds
save,filename=outfile,tw0_noaa,tw_noaa,tb_noaa,tb_raob,bias,jds_bias

stop
end
